Data Models
========================================================

Metadata
-----------------------------------------


.. toctree::
    :maxdepth: 2

    metadata <metadata>
    combiner <combiner>
    relationship <relationship>


Built-in Inspectors and InspectorManager
-----------------------------------------

.. toctree::
    :maxdepth: 3

    inspectors <inspectors/index>
